import { __decorate } from "tslib";
import { Generate, composePaths, createDefaultValue } from '@jsonforms/core';
import { designUnit } from '@microsoft/fast-components';
import { html, css, observable, customElement, FASTElement, repeat } from '@microsoft/fast-element';
import { logger } from '../../utils';
export const ArrayListWrapperRendererTemplate = (prefix = 'zero') => html `
  <template>
    ${repeat((x) => Array(x.control.data), html `
        <div class="array-list">
          <dispatch-renderer
            ?submitted=${(x, ctx) => ctx.parent.form.submitted}
            :dispatch=${(x, ctx) => ctx.parent.form.dispatch}
            :jsonforms=${(x, ctx) => ctx.parent.form.jsonforms}
            :prefix=${(x, ctx) => ctx.parent.form.prefix}
            :props=${(x, ctx) => ({
    uischema: ctx.parent.uiSchema,
    schema: ctx.parent.schema,
    renderers: ctx.parent.control.renderers,
    path: composePaths(ctx.parent.control.path, `${ctx.index}`),
    enabled: ctx.parent.control.enabled,
})}
          ></dispatch-renderer>
          <${prefix}-button
            appearance="lightweight"
            class="item-control-btn"
            data-test-id=${(x, ctx) => `${ctx.parent.control.path}-${ctx.index}-delete-item`}
            @click=${(x, ctx) => ctx.parent.deleteItem(ctx.index)}
          >
            <${prefix}-icon name="trash"></${prefix}-icon>
          </${prefix}-button>
        </div>
      `, { positioning: true })}
    <${prefix}-button
      appearance="lightweight"
      class="item-control-btn"
      data-test-id=${(x) => `${x.control.path}-add-item`}
      @click=${(x) => x.addItem()}
    >
      <${prefix}-icon name="plus"></${prefix}-icon>
      Add another
    </${prefix}-button>
  </template>
`;
const styles = css `
  :host {
    padding-left: calc(${designUnit} * 1px);
  }

  .array-list {
    display: flex;
    align-items: center;
  }

  .item-control-btn {
    color: rgb(135, 155, 166);
  }

  .item-control-btn:hover {
    color: var(--accent-foreground-hover);
  }
`;
let ArrayListWrapper = class ArrayListWrapper extends FASTElement {
    controlChanged() {
        this.schema = this.control.schema;
        if (this.control.uischema.options) {
            this.uiSchema = this.control.uischema.options.childUiSchema;
            return;
        }
        const arrayUiSchema = Generate.uiSchema(this.schema);
        this.uiSchema = Object.assign(Object.assign({}, arrayUiSchema), { type: 'HorizontalLayout' });
        logger.debug('Auto generated uiSchema for layout array:', this.uiSchema);
    }
    addItem() {
        this.control.addItem(this.control.path, createDefaultValue(this.control.schema, this.control.rootSchema))();
    }
    deleteItem(index) {
        this.control.removeItems(this.control.path, [index])();
    }
};
__decorate([
    observable
], ArrayListWrapper.prototype, "form", void 0);
__decorate([
    observable
], ArrayListWrapper.prototype, "control", void 0);
__decorate([
    observable
], ArrayListWrapper.prototype, "schema", void 0);
__decorate([
    observable
], ArrayListWrapper.prototype, "uiSchema", void 0);
ArrayListWrapper = __decorate([
    customElement({
        name: 'array-list-wrapper',
        styles,
        template: html `
    ${(x) => ArrayListWrapperRendererTemplate(x.form.prefix)}
  `,
    })
], ArrayListWrapper);
export { ArrayListWrapper };
